/**
 * 
 */

import java.sql.Connection;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;
import java.util.ArrayList;

/**
 * @author Musard Balliu
 *
 * @date Oct 16, 2015
 *
 */
public class NewDBParser {

	private DBConnection dbConn;

	/**
	 * Simple constructor. Initialises the DBConnection class.
	 */
	public NewDBParser() {
		dbConn = new DBConnection();
		System.out.println("Connected");
	}

	/**
	 * Executes a query and returns the result. Takes a String with the query to
	 * execute. Returns an ArrayList containing ArrayList as its elements. Each
	 * element holds data from the rows parsed from the result set returned from
	 * the query. Other data structures can be, of course, used such as 2D
	 * arrays, linked lists, hash maps and so on.
	 * 
	 * @param query
	 *            The query to execute.
	 * @return ArrayList
	 */
	public ArrayList<ArrayList> execQuery(String query) {
		// the list to return holding the queried data
		ArrayList<ArrayList> list = new ArrayList();

		ResultSet rs = null;
		Connection conn = null;
		Statement stmn = null;

		try {
			// get connection
			conn = dbConn.getConn();
			// create statement
			stmn = conn.createStatement();
			// execute statement
			if (query.contains("INSERT") || query.contains("DELETE")) {
				stmn.execute(query);
			} else {
				rs = stmn.executeQuery(query);

				while (rs.next()) {
					// the array list holding the data from
					// the current row parsed in the result set
					ArrayList dataList = new ArrayList();

					// get data by column name
					int id = rs.getInt("ID");
					String name = rs.getString("NAME");
					String address = rs.getString("ADDRESS");
					double salary = rs.getDouble("SALARY");

					// add to data list
					dataList.add(id);
					dataList.add(name);
					dataList.add(address);
					dataList.add(salary);

					// add to list to return
					list.add(dataList);

				} // end while()
			}
		} catch (SQLException ex) {
			// handle erros here
			System.out.println("\n" + "Something went wrong " + "while executing query..." + "\n");
			System.out.println("DBParser:SQLException: " + ex.getMessage());
			System.out.println("DBParser:SQLState: " + ex.getSQLState());
			System.out.println("DBParser:VendorError: " + ex.getErrorCode());
		} finally {
			// release resources
			try {
				if (rs != null) {
					rs.close();
				}
			} catch (SQLException ex) {
			}

			try {
				if (stmn != null) {
					stmn.close();
				}
			} catch (SQLException ex) {
			}

			try {
				if (conn != null) {
					conn.close();
				}
			} catch (SQLException ex) {
			}

		} // end try...catch...finally block

		// return the list
		return list;

	} // end getData()
}
